/***************************************************************************
 *   Copyright (C) 2009 by Marcel Hasler                                   *
 *   mahasler@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef CDEMU_H
#define CDEMU_H

#include <QString>
#include <QtDBus>

class CDEmu : public QObject
{
    Q_OBJECT

public:
    enum Result
    {
        Success,
        NoFreeDevice,
        FileNotFound,
        UnknownMountError,
        UnknownUnmountError,
        DaemonNotRunning,
        DaemonNotFound
    };

    static CDEmu* instance();

    int numDevices();
    bool daemonRunning();

    bool loaded(unsigned int device);
    QString filename(unsigned int device);

    Result mount(QString filename);
    Result unmount(unsigned int device);

private:
    CDEmu();
    ~CDEmu();

    void connectSlots(QDBusConnection *connection);
    void findCurrentBus();
    int nextFreeSlot();

    QDBusConnection m_sessionBus;
    QDBusConnection m_systemBus;
    QDBusConnection *m_currentBus;

signals:
    void deviceChanged(int device);
    void daemonChanged(bool running);

private slots:
    void slotDeviceChanged(int);
    void slotDaemonChanged();
};

#endif // CDEMU_H
