/***************************************************************************
 *   Copyright (C) 2009 by Marcel Hasler                                   *
 *   mahasler@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "cdemu.h"
#include "kdecdemu.h"
#include "messagebox.h"

#include <KCmdLineArgs>
#include <KMessageBox>
#include <KProcess>

#include <QTextStream>
QTextStream cout(stdout, QIODevice::WriteOnly);

//---------------------------------------------------------------------------------------------------------- //
//    Construction & destruction                                                                             //
//---------------------------------------------------------------------------------------------------------- //

KDECDEmu::KDECDEmu()
    : KUniqueApplication("kde_cdemu"),
      m_mainWindow(0)
{
}

//---------------------------------------------------------------------------------------------------------- //

KDECDEmu::~KDECDEmu()
{
}


//---------------------------------------------------------------------------------------------------------- //
//    Handle command line arguments or show the main window                                                  //
//---------------------------------------------------------------------------------------------------------- //

int KDECDEmu::newInstance()
{
    KCmdLineArgs *args = KCmdLineArgs::parsedArgs();

    if (args->isSet("mount"))
    {
        CDEmu::Result result = CDEmu::instance()->mount(QDir().absoluteFilePath(args->getOption("mount")));
        if (result != CDEmu::Success)
            MessageBox::error(result);
        if (!m_mainWindow)
            this->quit();
    }
    else if (args->isSet("unmount"))
    {
        CDEmu::Result result = CDEmu::instance()->unmount(args->getOption("unmount").toInt());
        if (result != CDEmu::Success)
            MessageBox::error(result);
        if (!m_mainWindow)
            this->quit();
    }
    else if (args->isSet("status"))
    {
        if (CDEmu::instance()->daemonRunning())
        {
            int numDevices = CDEmu::instance()->numDevices();

            cout << "Drive" << "\t\t" << "Loaded" << "\t\t" << "File" << endl;
            for (int i = 0; i < numDevices; i++)
            {
                if (CDEmu::instance()->loaded(i))
                    cout << i << "\t\t" << "Yes" << "\t\t" << CDEmu::instance()->filename(i) << endl;
                else
                    cout << i << "\t\t" << "No" << "\t\t" << "None" << endl;
            }
        }
        else
            cout << i18n("CDEmu daemon not running.") << endl;

        if (!m_mainWindow)
            this->quit();
    }
    else
    {
        if (!m_mainWindow)
            m_mainWindow = new MainWindow();
    }

    args->clear();
    return 0;
}

//---------------------------------------------------------------------------------------------------------- //
